@@ -55,17 +55,17 @@ class XRaySettingsLazySettings:
 
 class XRayConfigurator:
 
-    def __int__(self, settings):
+    def __init__(self, settings, application=None) -> None:
         if isinstance(settings, ConfigParser):
             self.settings = XRaySettingsConfigParser(settings)
         else:
             self.settings = XRaySettingsLazySettings(settings)
+
         self._init_xray(self.settings)
 
-    def __init__(self, settings, application) -> None:
-        self.__int__(settings)
         if not self.settings.enabled:
             return
+
         if self.settings.sqlalchemy:
             logging.info("XRayFlaskSqlAlchemy enabled")
             XRayFlaskSqlAlchemy(application)
